# pybes3

`pybes3` is an **unofficial** python module that aims to make BES3 user easier to work with Python.


It is recommended to take a look at these Python modules before using `pybes3`:

* `awkward`: A Python module that can handle ragged-like array. See [awkward-doc](https://awkward-array.org/doc/stable/index.html) to learn how to work with ragged-like array.
* `uproot`: A ROOT I/O Python module. If you want to write something into ROOT file (not as BES3 format!), see [uproot-doc](https://uproot.readthedocs.io/en/stable/) for further information.
